@@ -51,7 +51,7 @@ struct subset_summary {
   double total_sketch_weight;
 };
 
-template <typename T, typename S, typename A> class var_opt_union; // forward declaration
+template <typename T, typename A> class var_opt_union; // forward declaration
 
 namespace var_opt_constants {
     const resize_factor DEFAULT_RESIZE_FACTOR = resize_factor::X8;
@@ -60,7 +60,6 @@ namespace var_opt_constants {
 
 template<
   typename T,
-  typename S = serde<T>, // deprecated, to be removed in the next major version
   typename A = std::allocator<T>
 >
 class var_opt_sketch {
@@ -142,7 +141,7 @@ class var_opt_sketch {
      * @param instance of a SerDe
      * @return size in bytes needed to serialize this sketch
      */
-    template<typename TT = T, typename SerDe = S, typename std::enable_if<std::is_arithmetic<TT>::value, int>::type = 0>
+    template<typename TT = T, typename SerDe = serde<T>, typename std::enable_if<std::is_arithmetic<TT>::value, int>::type = 0>
     inline size_t get_serialized_size_bytes(const SerDe& sd = SerDe()) const;
 
     /**
@@ -151,7 +150,7 @@ class var_opt_sketch {
      * @param instance of a SerDe
      * @return size in bytes needed to serialize this sketch
      */
-    template<typename TT = T, typename SerDe = S, typename std::enable_if<!std::is_arithmetic<TT>::value, int>::type = 0>
+    template<typename TT = T, typename SerDe = serde<T>, typename std::enable_if<!std::is_arithmetic<TT>::value, int>::type = 0>
     inline size_t get_serialized_size_bytes(const SerDe& sd = SerDe()) const;
 
     // This is a convenience alias for users
@@ -166,7 +165,7 @@ class var_opt_sketch {
      * @param header_size_bytes space to reserve in front of the sketch
      * @param instance of a SerDe
      */
-    template<typename SerDe = S>
+    template<typename SerDe = serde<T>>
     vector_bytes serialize(unsigned header_size_bytes = 0, const SerDe& sd = SerDe()) const;
 
     /**
@@ -174,19 +173,9 @@ class var_opt_sketch {
      * @param os output stream
      * @param instance of a SerDe
      */
-    template<typename SerDe = S>
+    template<typename SerDe = serde<T>>
     void serialize(std::ostream& os, const SerDe& sd = SerDe()) const;
 
-    /**
-     * This method deserializes a sketch from a given stream.
-     * @param is input stream
-     * @param instance of an Allocator
-     * @return an instance of a sketch
-     *
-     * Deprecated, to be removed in the next major version
-     */
-    static var_opt_sketch deserialize(std::istream& is, const A& allocator = A());
-
     /**
      * This method deserializes a sketch from a given stream.
      * @param is input stream
@@ -194,20 +183,9 @@ class var_opt_sketch {
      * @param instance of an Allocator
      * @return an instance of a sketch
      */
-    template<typename SerDe = S>
+    template<typename SerDe = serde<T>>
     static var_opt_sketch deserialize(std::istream& is, const SerDe& sd = SerDe(), const A& allocator = A());
 
-    /**
-     * This method deserializes a sketch from a given array of bytes.
-     * @param bytes pointer to the array of bytes
-     * @param size the size of the array
-     * @param instance of an Allocator
-     * @return an instance of a sketch
-     *
-     * Deprecated, to be removed in the next major version
-     */
-    static var_opt_sketch deserialize(const void* bytes, size_t size, const A& allocator = A());
-
     /**
      * This method deserializes a sketch from a given array of bytes.
      * @param bytes pointer to the array of bytes
@@ -216,7 +194,7 @@ class var_opt_sketch {
      * @param instance of an Allocator
      * @return an instance of a sketch
      */
-    template<typename SerDe = S>
+    template<typename SerDe = serde<T>>
     static var_opt_sketch deserialize(const void* bytes, size_t size, const SerDe& sd = SerDe(), const A& allocator = A());
 
     /**
@@ -303,10 +281,9 @@ class var_opt_sketch {
                    std::unique_ptr<double, weights_deleter> weights, uint32_t num_marks_in_h,
                    std::unique_ptr<bool, marks_deleter> marks, const A& allocator);
 
-    friend class var_opt_union<T,S,A>;
+    friend class var_opt_union<T, A>;
     var_opt_sketch(const var_opt_sketch& other, bool as_sketch, uint64_t adjusted_n);
-    var_opt_sketch(T* data, double* weights, size_t len, uint32_t k, uint64_t n, uint32_t h_count, uint32_t r_count, double total_wt_r, const A& allocator);
-
+    
     string<A> items_to_string(bool print_gap) const;
 
     // internal-use-only update
@@ -368,59 +345,72 @@ class var_opt_sketch {
     class iterator;
 };
 
-template<typename T, typename S, typename A>
-class var_opt_sketch<T, S, A>::const_iterator : public std::iterator<std::input_iterator_tag, T> {
+template<typename T, typename A>
+class var_opt_sketch<T, A>::const_iterator {
 public:
+  using iterator_category = std::input_iterator_tag;
+  using value_type = std::pair<const T&, const double>;
+  using difference_type = void;
+  using pointer = const return_value_holder<value_type>;
+  using reference = const value_type;
+
   const_iterator(const const_iterator& other);
   const_iterator& operator++();
   const_iterator& operator++(int);
   bool operator==(const const_iterator& other) const;
   bool operator!=(const const_iterator& other) const;
-  const std::pair<const T&, const double> operator*() const;
+  reference operator*() const;
+  pointer operator->() const;
 
 private:
-  friend class var_opt_sketch<T,S,A>;
-  friend class var_opt_union<T,S,A>;
+  friend class var_opt_sketch<T, A>;
+  friend class var_opt_union<T, A>;
 
   // default iterator over full sketch
-  const_iterator(const var_opt_sketch<T,S,A>& sk, bool is_end);
+  const_iterator(const var_opt_sketch<T, A>& sk, bool is_end);
   
-  // iterates over only one of the H or R region, optionally applying weight correction
-  // to R region (can correct for numerical precision issues)
-  const_iterator(const var_opt_sketch<T,S,A>& sk, bool is_end, bool use_r_region);
+  // iterates over only one of the H or R regions
+  // does not apply weight correction
+  const_iterator(const var_opt_sketch<T, A>& sk, bool is_end, bool use_r_region);
 
   bool get_mark() const;
 
-  const var_opt_sketch<T,S,A>* sk_;
+  const var_opt_sketch<T, A>* sk_;
   double cum_r_weight_; // used for weight correction
   double r_item_wt_;
   size_t idx_;
   const size_t final_idx_;
-//  bool weight_correction_;
 };
 
 // non-const iterator for internal use
-template<typename T, typename S, typename A>
-class var_opt_sketch<T, S, A>::iterator : public std::iterator<std::input_iterator_tag, T> {
+template<typename T, typename A>
+class var_opt_sketch<T, A>::iterator {
 public:
+  using iterator_category = std::input_iterator_tag;
+  using value_type = std::pair<T&, double>;
+  using difference_type = void;
+  using pointer = return_value_holder<value_type>;
+  using reference = value_type;
+
   iterator(const iterator& other);
   iterator& operator++();
   iterator& operator++(int);
   bool operator==(const iterator& other) const;
   bool operator!=(const iterator& other) const;
-  std::pair<T&, double> operator*();
+  reference operator*();
+  pointer operator->();
 
 private:
-  friend class var_opt_sketch<T,S,A>;
-  friend class var_opt_union<T,S,A>;
+  friend class var_opt_sketch<T, A>;
+  friend class var_opt_union<T, A>;
   
   // iterates over only one of the H or R region, applying weight correction
   // if iterating over R region (can correct for numerical precision issues)
-  iterator(const var_opt_sketch<T,S,A>& sk, bool is_end, bool use_r_region);
+  iterator(const var_opt_sketch<T, A>& sk, bool is_end, bool use_r_region);
 
   bool get_mark() const;
 
-  const var_opt_sketch<T,S,A>* sk_;
+  const var_opt_sketch<T, A>* sk_;
   double cum_r_weight_; // used for weight correction
   double r_item_wt_;
   size_t idx_;
