@@ -32,7 +32,7 @@ std::ostream& operator<<(std::ostream& os, const three_doubles& tuple) {
 
 }
 
-#include <catch.hpp>
+#include <catch2/catch.hpp>
 #include <tuple_sketch.hpp>
 
 namespace datasketches {
@@ -56,7 +56,13 @@ TEST_CASE("tuple sketch float: empty", "[tuple_sketch]") {
   REQUIRE(!update_sketch.is_estimation_mode());
   REQUIRE(update_sketch.get_estimate() == 0);
   REQUIRE(update_sketch.get_lower_bound(1) == 0);
+  REQUIRE(update_sketch.get_lower_bound(1, 1) == 0);
+  REQUIRE(update_sketch.get_lower_bound(1, update_sketch.get_num_retained()) == 0);
+  REQUIRE(update_sketch.get_lower_bound(1, update_sketch.get_num_retained()+1) == 0);
   REQUIRE(update_sketch.get_upper_bound(1) == 0);
+  REQUIRE(update_sketch.get_upper_bound(1, 1) == 0);
+  REQUIRE(update_sketch.get_upper_bound(1, update_sketch.get_num_retained()) == 0);
+  REQUIRE(update_sketch.get_upper_bound(1, update_sketch.get_num_retained()+1) == 0);
   REQUIRE(update_sketch.get_theta() == 1);
   REQUIRE(update_sketch.get_num_retained() == 0);
   REQUIRE(update_sketch.is_ordered());
@@ -67,7 +73,11 @@ TEST_CASE("tuple sketch float: empty", "[tuple_sketch]") {
   REQUIRE(!compact_sketch.is_estimation_mode());
   REQUIRE(compact_sketch.get_estimate() == 0);
   REQUIRE(compact_sketch.get_lower_bound(1) == 0);
+  REQUIRE(compact_sketch.get_lower_bound(1, 1) == 0);
+  REQUIRE(compact_sketch.get_lower_bound(1, update_sketch.get_num_retained()) == 0);
   REQUIRE(compact_sketch.get_upper_bound(1) == 0);
+  REQUIRE(compact_sketch.get_upper_bound(1, 1) == 0);
+  REQUIRE(compact_sketch.get_upper_bound(1, update_sketch.get_num_retained()) == 0);
   REQUIRE(compact_sketch.get_theta() == 1);
   REQUIRE(compact_sketch.get_num_retained() == 0);
   REQUIRE(compact_sketch.is_ordered());
@@ -110,7 +120,11 @@ TEST_CASE("tuple sketch float: exact mode", "[tuple_sketch]") {
   REQUIRE_FALSE(update_sketch.is_estimation_mode());
   REQUIRE(update_sketch.get_estimate() == 2);
   REQUIRE(update_sketch.get_lower_bound(1) == 2);
+  REQUIRE(update_sketch.get_lower_bound(1, 1) == 1);
+  REQUIRE(update_sketch.get_lower_bound(1, update_sketch.get_num_retained()) == 2);
   REQUIRE(update_sketch.get_upper_bound(1) == 2);
+  REQUIRE(update_sketch.get_upper_bound(1, 1) == 1);
+  REQUIRE(update_sketch.get_upper_bound(1, update_sketch.get_num_retained()) == 2);
   REQUIRE(update_sketch.get_theta() == 1);
   REQUIRE(update_sketch.get_num_retained() == 2);
   REQUIRE_FALSE(update_sketch.is_ordered());
@@ -127,7 +141,11 @@ TEST_CASE("tuple sketch float: exact mode", "[tuple_sketch]") {
   REQUIRE_FALSE(compact_sketch.is_estimation_mode());
   REQUIRE(compact_sketch.get_estimate() == 2);
   REQUIRE(compact_sketch.get_lower_bound(1) == 2);
+  REQUIRE(compact_sketch.get_lower_bound(1, 1) == 1);
+  REQUIRE(compact_sketch.get_lower_bound(1, compact_sketch.get_num_retained()) == 2);
   REQUIRE(compact_sketch.get_upper_bound(1) == 2);
+  REQUIRE(compact_sketch.get_upper_bound(1, 1) == 1);
+  REQUIRE(compact_sketch.get_upper_bound(1, compact_sketch.get_num_retained()) == 2);
   REQUIRE(compact_sketch.get_theta() == 1);
   REQUIRE(compact_sketch.get_num_retained() == 2);
   REQUIRE(compact_sketch.is_ordered());
@@ -146,7 +164,11 @@ TEST_CASE("tuple sketch float: exact mode", "[tuple_sketch]") {
     REQUIRE(!deserialized_sketch.is_estimation_mode());
     REQUIRE(deserialized_sketch.get_estimate() == 2);
     REQUIRE(deserialized_sketch.get_lower_bound(1) == 2);
+    REQUIRE(deserialized_sketch.get_lower_bound(1, 1) == 1);
+    REQUIRE(deserialized_sketch.get_lower_bound(1, deserialized_sketch.get_num_retained()) == 2);
     REQUIRE(deserialized_sketch.get_upper_bound(1) == 2);
+    REQUIRE(deserialized_sketch.get_upper_bound(1, 1) == 1);
+    REQUIRE(deserialized_sketch.get_upper_bound(1, deserialized_sketch.get_num_retained()) == 2);
     REQUIRE(deserialized_sketch.get_theta() == 1);
     REQUIRE(deserialized_sketch.get_num_retained() == 2);
     REQUIRE(deserialized_sketch.is_ordered());
@@ -160,7 +182,11 @@ TEST_CASE("tuple sketch float: exact mode", "[tuple_sketch]") {
     REQUIRE(!deserialized_sketch.is_estimation_mode());
     REQUIRE(deserialized_sketch.get_estimate() == 2);
     REQUIRE(deserialized_sketch.get_lower_bound(1) == 2);
+    REQUIRE(deserialized_sketch.get_lower_bound(1, 1) == 1);
+    REQUIRE(deserialized_sketch.get_lower_bound(1, deserialized_sketch.get_num_retained()) == 2);
     REQUIRE(deserialized_sketch.get_upper_bound(1) == 2);
+    REQUIRE(deserialized_sketch.get_upper_bound(1, 1) == 1);
+    REQUIRE(deserialized_sketch.get_upper_bound(1, deserialized_sketch.get_num_retained()) == 2);
     REQUIRE(deserialized_sketch.get_theta() == 1);
     REQUIRE(deserialized_sketch.get_num_retained() == 2);
     REQUIRE(deserialized_sketch.is_ordered());
